package jalview.bin.argparser;

/**
 * A helper class to keep an index of argument position with argument values
 */
public class ArgValue implements Comparable<ArgValue>
{
  private Arg arg;

  private int argIndex;

  private String value;

  // This id is set by a subVal id= to identify the product of this ArgValue
  // later. Set but not currently used.
  private String id;

  private SubVals subVals;

  protected ArgValue(Arg a, SubVals sv, String content, int argIndex)
  {
    this.arg = a;
    this.value = content;
    this.argIndex = argIndex;
    this.subVals = sv == null ? new SubVals("") : sv;
  }

  protected ArgValue(Arg a, String value, int argIndex)
  {
    this.arg = a;
    this.argIndex = argIndex;
    this.subVals = new SubVals(value);
    this.value = getSubVals().getContent();
  }

  public Arg getArg()
  {
    return arg;
  }

  public String getValue()
  {
    return value;
  }

  public int getArgIndex()
  {
    return argIndex;
  }

  protected void setId(String i)
  {
    id = i;
  }

  public String getId()
  {
    return id;
  }

  public SubVals getSubVals()
  {
    return subVals;
  }

  public String getSubVal(String key)
  {
    if (subVals == null || !subVals.has(key))
      return null;
    return subVals.get(key);
  }

  protected void putSubVal(String key, String val)
  {
    this.subVals.put(key, val);
  }

  @Override
  public int compareTo(ArgValue o)
  {
    return this.getArgIndex() - o.getArgIndex();
  }
}